@@ -6,9 +6,11 @@ from cell2cell import analysis
 from cell2cell import clustering
 from cell2cell import core
 from cell2cell import datasets
+from cell2cell import external
 from cell2cell import io
+from cell2cell import plotting
 from cell2cell import preprocessing
 from cell2cell import stats
 from cell2cell import utils
 
-__version__ = "0.2.2"
\ No newline at end of file
+__version__ = "0.3.1"
\ No newline at end of file
